@@ -7,7 +7,7 @@ def create_dtc_instance(max_depth, criterion = 'gini', min_samples_split = 2, mi
 
     Parameters
     ----------    
-    criterion : {gini, entropy}, default=gini
+    criterion : {“gini”, “entropy”}, default=”gini”
     max_depth : max depth
     min_samples_split : default=2
     min_samples_leaf : default=1
