@@ -5,15 +5,17 @@ from .DTC import *
 from .LR import *
 from .KNN import *
 import matplotlib.pyplot as plt
+from sklearn.base import BaseEstimator, ClassifierMixin
 from sklearn.model_selection import train_test_split
+from sklearn.ensemble import StackingClassifier
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.svm import SVC
 from sklearn.multiclass import OneVsOneClassifier, OneVsRestClassifier
 from keras.utils import to_categorical
 import numpy as np
-import time
-from sklearn.base import BaseEstimator, ClassifierMixin
 from tqdm import tqdm
+import time
+
 
 #region Performance Test. Compare NNRW with mainstream classifier models.
 
@@ -416,7 +418,7 @@ def homo_stacking(X, y, create_base_estimator, Ns = [1, 2, 5], Ls = [1, 2, 5, 10
     repeat = 10 # run multiple times to get the mean
     '''
 
-    pbar = tqdm(total = repeat * len(Ns) * len(Ls), position=0, leave=True) # stay on top
+    # pbar = tqdm(total = repeat * len(Ns) * len(Ls), position=0, leave=True) # stay on top
 
     plt.figure(figsize = (14, 6))
 
@@ -443,7 +445,7 @@ def homo_stacking(X, y, create_base_estimator, Ns = [1, 2, 5], Ls = [1, 2, 5, 10
 
                 acc = acc + clf.fit(X_train, y_train).score(X_test, y_test)
 
-                pbar.update()
+                # pbar.update()
 
             ACCs.append(acc / repeat)
 
